@@ -15,17 +15,20 @@ from salesforce_bulk.util import IteratorBytesIO
 import pandas as pd
 import requests
 import base64
-from typing import List, Tuple, Optional
+from typing import List, Tuple, Optional, Union, Type
 from collections import OrderedDict
 import sys
 sys.path.append("..")
 from custom_exceptions.salesforce_exceptions import *
 from utilities.df_utils import *
+from salesforce.decorators import *
+
 
 
 class Sf:
     _REGEX_PARSE_SOQL_FIELDS = "(?<=select)(.*?)(?<!, )(?=from)"
     _REGEX_PARSE_SOQL_OBJECT = "(?<!, from )(?<=from )\w*"
+    
     def __init__(self) -> None:
         self.filename: str = None
         self.os_platform: str = platform
@@ -60,20 +63,6 @@ class Sf:
         """
         Authenticates Salesforce and retrieves the auth token.
 
-        Example:
-        authenticate using unpacked kwargs from the load_credentials function
-            authenticate(**load_credentials(platform, 'credentials.xlsx')[0])
-
-        Return Example:
-            {'sf': <simple_salesforce.api.Salesforce at 0x24a045c7b50>,
-             'bulk': <salesforce_bulk.salesforce_bulk.SalesforceBulk at 0x24a045c7e20>,
-             'sfMeta': <sfdclib.session.SfdcSession at 0x24a044b3400>,
-             'tooling': <sfdclib.tooling.SfdcToolingApi at 0x24a045d17f0>,
-             'session_id': '00D3F000000FZCq!AQYAQHYfSLYGI9cTyjD...PuuzNnZNb3461sUGeUZ57ttE.GBawbt5h',
-             'instance': 'cslbehring-core--devr01.my.salesforce.com',
-             'sfMeta_is_connected': True,
-             'bulk_api_sessionId': '00D3F000000FZCq!AQYAQHYfSLYGI9cTyjD...PuuzNnZNb3461sUGeUZ57ttE.GBawbt5h'}
-
         Dependencies:
             from simple_salesforce import Salesforce
             from simple_salesforce import SalesforceLogin
@@ -433,63 +422,6 @@ class Sf:
 
         return pd.DataFrame(result)
 
-    def load_credentials(self,
-                                os_platform: Optional[str] = None, 
-                                filename: Optional[str] = None, 
-                                *args, **kwargs) -> Tuple[dict, pd.DataFrame]:
-        """
-        Loads the credential file from the current working directory 
-        and returns the credentials file dataframe.
-        Arguments:
-            os_platform (str - Optional): String value of the plaform for which
-            this script is ran on. i.e. "linux", "win32", "darwin"
-
-            filename (str - Optional): The name of the credentials.xlsx file in the current
-            working directory folder.
-
-
-        Example:
-            load_credentials(platform, 'credentials.xlsx')
-
-        Return Example:
-            ({'sfUsername': 'michael.pay@verteo.biopharma.com',
-              'sfPassword': 'aq539z12315123423TRP9',
-              'sfOrgId': '00T3T000000FZCq',
-              'isSandbox': True},
-              ## credentials.xlsx pandas dataframe ##
-            )
-
-        Dependencies:
-            from sys import platform
-            import pandas as pd
-            import os
-        """
-        self.os_platform = self.os_platform if os_platform is None else os_platform
-        self.filename = self.filename if filename is None else filename
-        
-        assert filename is not None, \
-            "Please provide a file name to the credentials file (i.e. Sf.load_credentials(filename='credentials.xlsx'))"
-        
-        if os_platform =="darwin" or os_platform == "linux" or os_platform == "linux2":
-            credentials = pd.read_excel(os.getcwd() + "/" + filename)
-        elif platform == "win32":
-            credentials = pd.read_excel(os.getcwd() + "\\" + filename)
-        else:
-            credentials = pd.DataFrame()
-        sfUsername = credentials['Salesforce Username'][0]
-        sfPassword = credentials['Salesforce Password'][0]
-        sfOrgId = credentials['Salesforce Org Id'][0]
-        isSandbox = True if credentials['Sandbox Org?'][0]=="Yes" else False
-        # networkURL = self.networkURL = credentials['Salesforce Username'][3]
-        # networkUserName = self.networkUserName = credentials['Salesforce Password'][3]
-        # networkPassword = self.networkPassword = credentials['Salesforce Org Id'][3]
-        # networkCountry = self.networkCountry = credentials['Sandbox Org?'][3]
-
-        return {'sfUsername':sfUsername, 
-                'sfPassword':sfPassword, 
-                'sfOrgId':sfOrgId, 
-                'isSandbox':isSandbox}, credentials
-
     def extract_bulk(self, og_query: str, 
                         excludedFields: Optional[List] = []) -> pd.DataFrame:
         """
@@ -767,6 +699,41 @@ class Sf:
         sfRTDF.drop(columns="attributes", inplace = True)
         return sfRTDF
 
+    
+    @serialze_zeep
+    def metadata_read(self, metadata_type: str, fullName: str):
+        return getattr(self.sf.mdapi, metadata_type).read(fullName)
+
+    def metadata_delete(self, metadata_type: str, fullName: str):
+        return getattr(self.sf.mdapi, metadata_type).delete(fullName)
+
+    def metadata_update(self, metadata_type: str, parsed_metadata: dict):
+        mdapi_object = getattr(self.sf.mdapi, metadata_type)()
+        for key in parsed_metadata:
+            setattr(mdapi_object, key, parsed_metadata[key])
+        getattr(self.sf.mdapi, metadata_type).update(mdapi_object)
+        return mdapi_object
+
+    def metadata_create(self, metadata_type: str, parsed_metadata: dict):
+        mdapi_object = getattr(self.sf.mdapi, metadata_type)()
+        for key in parsed_metadata:
+            setattr(mdapi_object, key, parsed_metadata[key])
+        getattr(self.sf.mdapi, metadata_type).create(mdapi_object)
+        return mdapi_object
+
+    def metadata_list(self, metadata_type: str) -> list:
+        query = self.sf.mdapi.ListMetadataQuery(type=metadata_type)
+        query_response = self.sf.mdapi.list_metadata(query)
+        return query_response
+    
+    def metadata_rename(self, metadata_type: str, previous_name: str, new_name: str): 
+        """
+        Renames the API name of SFDC metadata
+        """
+        getattr(self.sf.mdapi, metadata_type).rename(previous_name, new_name)
+    
+
+
     def sf_api_call(self, action, parameters = {}, method = 'get', data = {}):
         """
         Helper function to make calls to Salesforce REST API.
@@ -791,4 +758,5 @@ class Sf:
             else:
                 return r.json()
         else:
-            raise Exception('API error when calling %s : %s' % (r.url, r.content))
\ No newline at end of file
+            raise Exception('API error when calling %s : %s' % (r.url, r.content))
+    
\ No newline at end of file
