@@ -6,6 +6,8 @@ import json
 from typing import List, Tuple, Optional, Union, Type, OrderedDict, Iterable
 import numpy as np
 import sys
+import importlib.resources
+
 
 class Vn:
     def __init__(self):
@@ -29,8 +31,10 @@ class Vn:
         #----------------------------------------------------------------
         # Load Network API Json
         self.network_api_json: dict = None
-        with open('network_api_v25.json', encoding="utf-8") as file:
+        with importlib.resources.open_text("veevatools", "data.json") as file:
             self.network_api_json = json.load(file)
+        # with open('network_api_v25.json', encoding="utf-8") as file:
+        #     self.network_api_json = json.load(file)
         self.network_api_parsed: dict = self.__parse_network_api_json(self.network_api_json)
 
     
